#!/usr/bin/env python

# This is a script which acts as a shared library linker, except an object ready
# for static linking is created instead
#
# If the input file is: filename.so
#
# The static library is: filename.so.o
# The library is:        libnumpy_filename.a

import sys
import subprocess
from os import environ
from os import path

ld   = environ.get('ARM_LD')
ar   = environ.get('ARM_AR')
arch = environ.get('ARCH', 'armv7')
base = environ.get('LIB_BASE', 'lib_')

# Get the important settings (and ignore everything else)
outfile = sys.argv[sys.argv.index('-o')+1]
libs    = [x for x in sys.argv if x.startswith('-l')]
libdirs = [x for x in sys.argv if x.startswith('-L')]
objects = [x for x in sys.argv if x.endswith('.o')]

# Create expected output files so the build continues
subprocess.call(['touch', outfile])
subprocess.call(['touch', outfile + '.libs'])

outfile_parts = list(path.split(outfile[:-3]))
outfile_parts[-1] = '%s%s.a' % (base, outfile_parts[-1])

arfile = path.join(*outfile_parts)

# Create the static library
subprocess.call([ld, '-r', '-o', outfile + '.o', '-arch', arch] + objects)
subprocess.call([ar, '-r', arfile] + objects)
